@@ -543,7 +543,7 @@ def FieldDetermination(Fields=1,plot=False,**kwargs):
         for i in range(len(rect)):
             ax.add_patch(rect[i])
 
-    if type(ret) == True:
+    if ret == True:
             return fields
 
 def Interaction(data,bodyPart,fields,fps=30):
